from mastercardapicore import *

# import apis resourceconfig
from mastercardspendingpulse.resourceconfig import ResourceConfig


# import apis into api package
from mastercardspendingpulse.gasweekly import *
from mastercardspendingpulse.parameters import *
from mastercardspendingpulse.spendingpulsereport import *
from mastercardspendingpulse.subscription import *
